{-# LANGUAGE OverloadedStrings #-}

module Fake.Provider.Person.EN_US
  ( personName
  , femaleName
  , maleName
  , femalePrefix
  , femalePrefixList
  , malePrefix
  , malePrefixList
  , femaleSuffix
  , femaleSuffixList
  , maleSuffix
  , maleSuffixList
  , firstName
  , femaleFirstName
  , femaleNameList
  , maleFirstName
  , maleNameList
  , lastName
  , lastNameList
  ) where

------------------------------------------------------------------------------
import           Data.Bifunctor
import           Data.Text (Text)
------------------------------------------------------------------------------
import Fake.Combinators
import Fake.Provider.Lang
import Fake.Types
------------------------------------------------------------------------------

personName :: FGen Text
personName = oneof [femaleName, maleName]

femaleName :: FGen Text
femaleName = phraseText <$> frequency
    [ (5, phrase [femaleFirstName, lastName])
    , (1, phrase [femalePrefix, femaleFirstName, lastName])
    , (1, phrase [femaleFirstName, lastName, femaleSuffix])
    , (1, phrase [femalePrefix, femaleFirstName, lastName, femaleSuffix])
    ]

maleName :: FGen Text
maleName = phraseText <$> frequency
    [ (5, phrase [maleFirstName, lastName])
    , (1, phrase [malePrefix, maleFirstName, lastName])
    , (1, phrase [maleFirstName, lastName, maleSuffix])
    , (1, phrase [malePrefix, maleFirstName, lastName, maleSuffix])
    ]

femalePrefix :: FGen SingleWord
femalePrefix = elements femalePrefixList

femalePrefixList :: [SingleWord]
femalePrefixList = ["Mrs.", "Ms.", "Miss", "Dr."]

malePrefix :: FGen SingleWord
malePrefix = elements malePrefixList

malePrefixList :: [SingleWord]
malePrefixList = ["Mr.", "Dr."]

femaleSuffix :: FGen SingleWord
femaleSuffix = elements femaleSuffixList

femaleSuffixList :: [SingleWord]
femaleSuffixList = ["MD", "DDS", "PhD", "DVM"]

maleSuffix :: FGen SingleWord
maleSuffix = elements maleSuffixList

maleSuffixList :: [SingleWord]
maleSuffixList = ["Jr.", "Sr.", "I", "II", "III","IV", "V", "MD", "DDS", "PhD", "DVM"]

firstName :: FGen SingleWord
firstName = oneof [femaleFirstName, maleFirstName]

femaleFirstName :: FGen SingleWord
femaleFirstName = frequency $ map (second (return . SingleWord)) femaleNameList

------------------------------------------------------------------------------
-- | List of the 1000 most common U.S. female names and the number of people
-- with that name.  This is from a dataset of 302037244 names from the Social
-- Security Adminisatration between 1910 and 2015.
femaleNameList :: [(Int, Text)]
femaleNameList = femaleNameList00
              ++ femaleNameList01
              ++ femaleNameList02
              ++ femaleNameList03
              ++ femaleNameList04
              ++ femaleNameList05
              ++ femaleNameList06
              ++ femaleNameList07
              ++ femaleNameList08
              ++ femaleNameList09

femaleNameList00 :: [(Int, Text)]
femaleNameList00 =
    [ (3733620,"Mary")
    , (1568111,"Patricia")
    , (1510283,"Elizabeth")
    , (1463109,"Jennifer")
    , (1446736,"Linda")
    , (1423313,"Barbara")
    , (1124104,"Margaret")
    , (1108550,"Susan")
    , (1051986,"Dorothy")
    , (1039665,"Jessica")
    , (1015445,"Sarah")
    , (984086,"Betty")
    , (984075,"Nancy")
    , (982629,"Karen")
    , (962363,"Lisa")
    , (896357,"Helen")
    , (870837,"Sandra")
    , (837145,"Ashley")
    , (830171,"Kimberly")
    , (826596,"Donna")
    , (812163,"Carol")
    , (805087,"Michelle")
    , (803947,"Emily")
    , (770574,"Amanda")
    , (747383,"Laura")
    , (747264,"Melissa")
    , (736141,"Deborah")
    , (734863,"Stephanie")
    , (732041,"Rebecca")
    , (730475,"Ruth")
    , (730366,"Anna")
    , (718600,"Sharon")
    , (703771,"Cynthia")
    , (703687,"Kathleen")
    , (679937,"Shirley")
    , (677040,"Amy")
    , (656393,"Angela")
    , (622324,"Virginia")
    , (609624,"Catherine")
    , (604231,"Brenda")
    , (600165,"Katherine")
    , (591466,"Pamela")
    , (580795,"Nicole")
    , (574453,"Christine")
    , (559306,"Samantha")
    , (550629,"Janet")
    , (548928,"Rachel")
    , (548353,"Carolyn")
    , (547697,"Debra")
    , (534173,"Emma")
    , (530081,"Frances")
    , (526776,"Maria")
    , (522137,"Heather")
    , (514882,"Diane")
    , (514467,"Evelyn")
    , (503360,"Julie")
    , (502941,"Joyce")
    , (490835,"Martha")
    , (475580,"Joan")
    , (474172,"Alice")
    , (468415,"Kelly")
    , (468137,"Christina")
    , (463124,"Victoria")
    , (462322,"Marie")
    , (460700,"Lauren")
    , (449716,"Ann")
    , (448187,"Doris")
    , (447229,"Judith")
    , (445985,"Jean")
    , (436759,"Cheryl")
    , (433784,"Megan")
    , (431669,"Kathryn")
    , (424473,"Andrea")
    , (416950,"Jacqueline")
    , (415303,"Rose")
    , (409399,"Julia")
    , (408124,"Sara")
    , (407918,"Grace")
    , (407310,"Gloria")
    , (405590,"Teresa")
    , (404080,"Hannah")
    , (402178,"Janice")
    , (394752,"Mildred")
    , (390113,"Olivia")
    , (387443,"Theresa")
    , (377964,"Judy")
    , (373578,"Beverly")
    , (368888,"Denise")
    , (366196,"Marilyn")
    , (365524,"Amber")
    , (362848,"Danielle")
    , (356785,"Lillian")
    , (356329,"Madison")
    , (356164,"Brittany")
    , (354817,"Jane")
    , (352103,"Diana")
    , (338555,"Lori")
    , (334089,"Tiffany")
    , (331564,"Natalie")
    , (330711,"Abigail")
    ]

femaleNameList01 :: [(Int, Text)]
femaleNameList01 =
    [ (330643,"Kathy")
    , (330129,"Kayla")
    , (329816,"Alexis")
    , (329507,"Tammy")
    , (325324,"Crystal")
    , (317163,"Phyllis")
    , (317018,"Lois")
    , (316759,"Bonnie")
    , (311126,"Taylor")
    , (308984,"Erin")
    , (308530,"Ruby")
    , (307037,"Charlotte")
    , (306682,"Irene")
    , (304630,"Anne")
    , (298481,"Alyssa")
    , (294367,"Sophia")
    , (292329,"Shannon")
    , (288489,"Peggy")
    , (286558,"Tina")
    , (286469,"Robin")
    , (285392,"Dawn")
    , (284851,"Isabella")
    , (284477,"Allison")
    , (281307,"Louise")
    , (276494,"Rita")
    , (276134,"Wanda")
    , (275894,"Annie")
    , (273106,"Paula")
    , (268512,"Norma")
    , (264262,"Jamie")
    , (261906,"Leslie")
    , (261840,"Connie")
    , (261273,"Audrey")
    , (258283,"Wendy")
    , (257883,"Marjorie")
    , (256951,"Josephine")
    , (254646,"Courtney")
    , (253406,"Cindy")
    , (252530,"Elaine")
    , (252385,"Eleanor")
    , (250991,"Valerie")
    , (249113,"Ellen")
    , (247958,"Vanessa")
    , (247714,"Tracy")
    , (246263,"Florence")
    , (243962,"Brianna")
    , (243507,"Monica")
    , (238105,"Jasmine")
    , (235367,"Melanie")
    , (234805,"Sheila")
    , (234638,"April")
    , (231806,"Ella")
    , (227572,"Erica")
    , (226931,"Sherry")
    , (225970,"Edna")
    , (225823,"Sylvia")
    , (223301,"Alexandra")
    , (222760,"Carrie")
    , (220793,"Michele")
    , (220108,"Alicia")
    , (217600,"Gladys")
    , (217496,"Katie")
    , (215521,"Kristen")
    , (215372,"Suzanne")
    , (213013,"Ava")
    , (212131,"Edith")
    , (210434,"Esther")
    , (209024,"Veronica")
    , (208576,"Eva")
    , (207877,"Joanne")
    , (207146,"Anita")
    , (207100,"Morgan")
    , (206024,"Dolores")
    , (205655,"Rhonda")
    , (205368,"Jill")
    , (203890,"Leah")
    , (203870,"Geraldine")
    , (203103,"Lorraine")
    , (201802,"Thelma")
    , (201335,"Clara")
    , (201129,"Caroline")
    , (200378,"Darlene")
    , (200231,"Pauline")
    , (198192,"Juanita")
    , (197855,"Gail")
    , (196798,"Holly")
    , (196397,"Lucille")
    , (195066,"Ethel")
    , (194814,"Hazel")
    , (194529,"Sally")
    , (188987,"Vivian")
    , (187850,"Dana")
    , (186620,"Mia")
    , (184838,"Debbie")
    , (184193,"Chloe")
    , (183848,"June")
    , (183845,"Brooke")
    , (180439,"Renee")
    , (179599,"Eileen")
    , (177977,"Lynn")
    ]

femaleNameList02 :: [(Int, Text)]
femaleNameList02 =
    [ (176811,"Kristin")
    , (176703,"Kim")
    , (175442,"Jo")
    , (171625,"Tara")
    , (168701,"Regina")
    , (168113,"Madeline")
    , (167328,"Cathy")
    , (165623,"Claire")
    , (164531,"Roberta")
    , (164214,"Cassandra")
    , (163496,"Bernice")
    , (163184,"Marion")
    , (162561,"Laurie")
    , (161886,"Annette")
    , (161684,"Loretta")
    , (160439,"Beatrice")
    , (160096,"Stacy")
    , (159880,"Sydney")
    , (159764,"Kaitlyn")
    , (158997,"Colleen")
    , (158333,"Jeanne")
    , (157135,"Lucy")
    , (156205,"Chelsea")
    , (155104,"Jeanette")
    , (155052,"Molly")
    , (154910,"Beth")
    , (153451,"Lindsey")
    , (152956,"Joann")
    , (151763,"Haley")
    , (151224,"Savannah")
    , (150771,"Vicki")
    , (150651,"Yvonne")
    , (150195,"Rosemary")
    , (149161,"Gina")
    , (148398,"Hailey")
    , (145939,"Rosa")
    , (145054,"Stacey")
    , (144736,"Carla")
    , (143381,"Terri")
    , (143254,"Amelia")
    , (143231,"Kelsey")
    , (140785,"Destiny")
    , (140698,"Jenna")
    , (140375,"Shelby")
    , (140184,"Naomi")
    , (139793,"Maureen")
    , (139162,"Lydia")
    , (139008,"Heidi")
    , (137535,"Sue")
    , (137406,"Arlene")
    , (136939,"Bertha")
    , (133137,"Sabrina")
    , (132940,"Kristina")
    , (132724,"Constance")
    , (132249,"Paige")
    , (131633,"Melinda")
    , (131590,"Wilma")
    , (131323,"Deanna")
    , (130504,"Carmen")
    , (130304,"Elsie")
    , (129331,"Charlene")
    , (129298,"Joy")
    , (129200,"Jessie")
    , (129124,"Georgia")
    , (129053,"Stella")
    , (128948,"Marian")
    , (128714,"Katelyn")
    , (128631,"Marcia")
    , (127916,"Tamara")
    , (127669,"Gabrielle")
    , (127267,"Jordan")
    , (126853,"Lindsay")
    , (125405,"Marlene")
    , (124635,"Alma")
    , (123694,"Faith")
    , (123662,"Ida")
    , (122641,"Lily")
    , (121135,"Willie")
    , (120982,"Erika")
    , (119834,"Gertrude")
    , (119580,"Claudia")
    , (117853,"Tonya")
    , (117331,"Mackenzie")
    , (116494,"Marissa")
    , (116295,"Kaylee")
    , (115331,"Patsy")
    , (114961,"Vera")
    , (114712,"Agnes")
    , (114228,"Delores")
    , (113544,"Tanya")
    , (112821,"Daisy")
    , (112301,"Priscilla")
    , (112063,"Lillie")
    , (112025,"Violet")
    , (111939,"Alexa")
    , (111627,"Gwendolyn")
    , (111475,"Nina")
    , (111010,"Autumn")
    , (109714,"Caitlin")
    , (108383,"Yolanda")
    ]

femaleNameList03 :: [(Int, Text)]
femaleNameList03 =
    [ (107842,"Nora")
    , (107773,"Angelina")
    , (107422,"Carole")
    , (107359,"Vickie")
    , (107220,"Alison")
    , (106251,"Sofia")
    , (106187,"Miranda")
    , (106018,"Maxine")
    , (105827,"Zoe")
    , (105347,"Glenda")
    , (104218,"Brandy")
    , (103457,"Addison")
    , (103029,"Isabel")
    , (103012,"Gabriella")
    , (102969,"Bessie")
    , (101216,"Marsha")
    , (100761,"Mariah")
    , (100235,"Pearl")
    , (100149,"Kylie")
    , (99791,"Brandi")
    , (99338,"Margie")
    , (98822,"Avery")
    , (97602,"Miriam")
    , (97495,"Katrina")
    , (97354,"Viola")
    , (97344,"Nellie")
    , (97181,"Lena")
    , (96684,"Makayla")
    , (96610,"Jocelyn")
    , (96120,"Billie")
    , (96005,"Toni")
    , (95658,"Kara")
    , (95602,"Joanna")
    , (95385,"Christy")
    , (94089,"Genevieve")
    , (93865,"Ana")
    , (93783,"Bethany")
    , (93694,"Sophie")
    , (93552,"Terry")
    , (93356,"Kay")
    , (93339,"Penny")
    , (93318,"Sierra")
    , (93039,"Whitney")
    , (92827,"Natasha")
    , (92751,"Meghan")
    , (92337,"Dianne")
    , (92244,"Alexandria")
    , (91702,"Aubrey")
    , (91172,"Kendra")
    , (90986,"Bailey")
    , (90678,"Jennie")
    , (90608,"Angel")
    , (90574,"Mattie")
    , (90463,"Sadie")
    , (89920,"Briana")
    , (89221,"Minnie")
    , (87872,"Melody")
    , (87076,"Myrtle")
    , (86807,"Felicia")
    , (86703,"Jackie")
    , (86480,"Ariana")
    , (86436,"Riley")
    , (86218,"Leona")
    , (85884,"Jenny")
    , (85847,"Cora")
    , (85529,"Angelica")
    , (85274,"Brooklyn")
    , (84678,"Maggie")
    , (84525,"Karla")
    , (84225,"Bridget")
    , (84109,"Tracey")
    , (83795,"Bobbie")
    , (83293,"Becky")
    , (82983,"Cecilia")
    , (82541,"Adriana")
    , (82162,"Misty")
    , (81810,"Maya")
    , (81689,"Candace")
    , (81611,"Shelly")
    , (81490,"Sherri")
    , (80978,"Kristine")
    , (80433,"Jacquelyn")
    , (80357,"Brittney")
    , (80280,"Hope")
    , (79821,"Arianna")
    , (79530,"Breanna")
    , (78984,"Desiree")
    , (78809,"Jillian")
    , (77083,"Rachael")
    , (77071,"Jodi")
    , (76960,"Dora")
    , (76872,"Geneva")
    , (76233,"Sheryl")
    , (75864,"Mae")
    , (75610,"Monique")
    , (74883,"Isabelle")
    , (74803,"Velma")
    , (74690,"Madelyn")
    , (74349,"Lynda")
    , (74197,"Kristi")
    ]

femaleNameList04 :: [(Int, Text)]
femaleNameList04 =
    [ (74128,"Aaliyah")
    , (74005,"Gabriela")
    , (73781,"Jade")
    , (73703,"Marguerite")
    , (73479,"Casey")
    , (72831,"Kelli")
    , (72576,"Harriet")
    , (72467,"Mabel")
    , (71940,"Summer")
    , (71503,"Krystal")
    , (70960,"Krista")
    , (70880,"Iris")
    , (70442,"Antoinette")
    , (70041,"Trinity")
    , (69871,"Shelley")
    , (68992,"Rebekah")
    , (68659,"Nevaeh")
    , (68627,"Lola")
    , (68202,"Belinda")
    , (68072,"Bianca")
    , (67896,"Kristy")
    , (67765,"Meredith")
    , (66468,"Layla")
    , (65668,"Eunice")
    , (65284,"Rosie")
    , (65099,"Sandy")
    , (64870,"Kate")
    , (64789,"Candice")
    , (64229,"Hilda")
    , (63887,"Zoey")
    , (63770,"Cheyenne")
    , (63596,"Janie")
    , (63471,"Gracie")
    , (62925,"Ramona")
    , (62348,"Irma")
    , (62190,"Susie")
    , (62019,"Elena")
    , (61762,"Ariel")
    , (61708,"Adrienne")
    , (61576,"Peyton")
    , (61452,"Nichole")
    , (61227,"Jeannette")
    , (61151,"Rosalie")
    , (60806,"Guadalupe")
    , (60667,"Sonya")
    , (60497,"Ada")
    , (60384,"Carly")
    , (60238,"Jada")
    , (60081,"Sonia")
    , (59621,"Marianne")
    , (59561,"Faye")
    , (59342,"Patty")
    , (58795,"Yvette")
    , (58756,"Robyn")
    , (58721,"Lynne")
    , (58711,"Hattie")
    , (58356,"Camille")
    , (58167,"Sheri")
    , (58113,"Alberta")
    , (58042,"Kennedy")
    , (57915,"Gayle")
    , (56976,"Verna")
    , (56513,"Maryann")
    , (56212,"Opal")
    , (56169,"Marcella")
    , (55980,"Kari")
    , (55936,"Valeria")
    , (55816,"Kaitlin")
    , (55677,"Gianna")
    , (55607,"Lee")
    , (55358,"Angie")
    , (55141,"Blanche")
    , (55080,"Tabitha")
    , (54982,"Elise")
    , (54904,"Natalia")
    , (54455,"Karina")
    , (54278,"Roxanne")
    , (53969,"Fannie")
    , (53954,"Genesis")
    , (53401,"Daniela")
    , (53211,"Abby")
    , (53102,"Lila")
    , (52985,"Alisha")
    , (52891,"Jody")
    , (52679,"Kendall")
    , (52429,"Lula")
    , (52224,"Inez")
    , (52145,"Mckenzie")
    , (51998,"Dianna")
    , (51858,"Cassidy")
    , (51614,"Skylar")
    , (51567,"Jan")
    , (51234,"Beulah")
    , (51111,"Mallory")
    , (50617,"Myra")
    , (50200,"Mikayla")
    , (50188,"Caitlyn")
    , (50112,"Traci")
    , (49914,"Celeste")
    , (49890,"Vicky")
    ]

femaleNameList05 :: [(Int, Text)]
femaleNameList05 =
    [ (49874,"Kirsten")
    , (49629,"Olga")
    , (49300,"Alana")
    , (49272,"Aimee")
    , (48408,"Kellie")
    , (48395,"Janelle")
    , (48281,"Camila")
    , (48201,"Mya")
    , (48029,"Harper")
    , (47804,"Bernadette")
    , (47770,"Lacey")
    , (47629,"Gretchen")
    , (47612,"Flora")
    , (47532,"Juliana")
    , (47512,"Muriel")
    , (47501,"Cristina")
    , (47408,"Dominique")
    , (47251,"Mamie")
    , (47193,"Nadine")
    , (46997,"Payton")
    , (46989,"Cara")
    , (46898,"Jaime")
    , (46786,"Allyson")
    , (46771,"Jordyn")
    , (46733,"Alejandra")
    , (46710,"Annabelle")
    , (46007,"Erma")
    , (45868,"Lana")
    , (45840,"Hayley")
    , (45812,"Michaela")
    , (45804,"Liliana")
    , (45752,"Jaclyn")
    , (45624,"Kerry")
    , (45588,"Bella")
    , (45535,"Marisa")
    , (45530,"Della")
    , (45380,"Rosemarie")
    , (44996,"Serenity")
    , (44978,"Kiara")
    , (44978,"Raquel")
    , (44956,"Janis")
    , (44848,"Shelia")
    , (44703,"Cecelia")
    , (44397,"Callie")
    , (44302,"Ellie")
    , (43961,"Latoya")
    , (43888,"Lilly")
    , (43631,"Kelley")
    , (43617,"Josie")
    , (43355,"Kylee")
    , (43299,"Lora")
    , (43058,"Betsy")
    , (43017,"Shawna")
    , (42987,"Johnnie")
    , (42911,"Paulette")
    , (42885,"Selena")
    , (42776,"Rochelle")
    , (42475,"Doreen")
    , (42253,"Christie")
    , (42248,"Ashlyn")
    , (42148,"Tessa")
    , (42048,"Penelope")
    , (41987,"Rylee")
    , (41938,"Patti")
    , (41749,"Celia")
    , (41721,"Ginger")
    , (41639,"Eloise")
    , (41592,"Ashlee")
    , (41486,"Reagan")
    , (41435,"Jasmin")
    , (41301,"Teri")
    , (41285,"Johanna")
    , (41275,"Esmeralda")
    , (40722,"Jana")
    , (40547,"Scarlett")
    , (40508,"Adrianna")
    , (39983,"Mable")
    , (39670,"Meagan")
    , (39550,"Aurora")
    , (39427,"Laverne")
    , (39313,"Alexia")
    , (39268,"Corinne")
    , (39227,"Mercedes")
    , (39190,"Mindy")
    , (39154,"Mona")
    , (38888,"Cassie")
    , (38788,"Ernestine")
    , (38682,"Lynette")
    , (38450,"Leticia")
    , (38449,"Giselle")
    , (38444,"Elisabeth")
    , (38275,"Darla")
    , (38146,"Jazmin")
    , (37960,"Estelle")
    , (37949,"Laurel")
    , (37900,"Shari")
    , (37738,"Adeline")
    , (37628,"Pat")
    , (37226,"Tricia")
    , (37160,"Dixie")
    ]

femaleNameList06 :: [(Int, Text)]
femaleNameList06 =
    [ (36923,"Nadia")
    , (36912,"Trisha")
    , (36868,"Ebony")
    , (36839,"Julianna")
    , (36794,"Mandy")
    , (36614,"Yesenia")
    , (36578,"Leigh")
    , (36475,"Stacie")
    , (36398,"Elisa")
    , (36365,"Henrietta")
    , (36096,"Allie")
    , (36064,"Nikki")
    , (36007,"Carolina")
    , (35877,"Makenzie")
    , (35873,"Tami")
    , (35760,"Kristie")
    , (35700,"Raven")
    , (35405,"Eliza")
    , (35099,"Eula")
    , (35096,"Kimberley")
    , (35083,"Alondra")
    , (34933,"Sonja")
    , (34862,"Kyla")
    , (34813,"Anastasia")
    , (34790,"Margarita")
    , (34740,"Alissa")
    , (34701,"Marla")
    , (34640,"Jayla")
    , (34632,"Ivy")
    , (34504,"Lorena")
    , (34399,"Kerri")
    , (34344,"Serena")
    , (34078,"Stefanie")
    , (33850,"Bonita")
    , (33579,"Olive")
    , (33559,"Tammie")
    , (33391,"Cheri")
    , (33375,"Lorene")
    , (33358,"Alaina")
    , (33322,"Jazmine")
    , (33271,"Tasha")
    , (33061,"Freda")
    , (33045,"Winifred")
    , (32765,"Hanna")
    , (32688,"Aliyah")
    , (32681,"Britney")
    , (32656,"Lucia")
    , (32634,"Mckenna")
    , (32582,"Madeleine")
    , (32503,"Leila")
    , (32364,"Sherrie")
    , (32307,"Piper")
    , (32214,"Clarissa")
    , (32177,"Justine")
    , (32108,"Bette")
    , (31959,"Katharine")
    , (31901,"Delaney")
    , (31855,"Tori")
    , (31767,"Deloris")
    , (31726,"Ronda")
    , (31721,"Jeannie")
    , (31618,"Bettie")
    , (31453,"Jewel")
    , (31443,"Sasha")
    , (31379,"Ciara")
    , (31340,"Pam")
    , (31318,"Khloe")
    , (31288,"Francine")
    , (31226,"Kyra")
    , (30974,"Melba")
    , (30957,"Mollie")
    , (30932,"Mariana")
    , (30927,"Patrice")
    , (30702,"Kira")
    , (30645,"Marina")
    , (30491,"Tatiana")
    , (30411,"Diamond")
    , (30316,"Shawn")
    , (30207,"Sallie")
    , (30168,"Alisa")
    , (30139,"Tracie")
    , (30117,"Marisol")
    , (30117,"Mayra")
    , (30042,"Lesley")
    , (30001,"Therese")
    , (29917,"Tia")
    , (29894,"Rachelle")
    , (29773,"Ashleigh")
    , (29674,"Kasey")
    , (29626,"Janine")
    , (29428,"Chelsey")
    , (29387,"Lucinda")
    , (29275,"Adele")
    , (29267,"Keri")
    , (29236,"Reba")
    , (29215,"Christa")
    , (29101,"Asia")
    , (29050,"Charity")
    , (29032,"Trina")
    , (28986,"Aubree")
    ]

femaleNameList07 :: [(Int, Text)]
femaleNameList07 =
    [ (28781,"London")
    , (28758,"Kassandra")
    , (28606,"Latasha")
    , (28507,"Nettie")
    , (28434,"Katelynn")
    , (28263,"Laila")
    , (28171,"Daphne")
    , (28146,"Rena")
    , (28020,"Dakota")
    , (28008,"Aria")
    , (27790,"Myrna")
    , (27699,"Lottie")
    , (27645,"Essie")
    , (27618,"Eliana")
    , (27575,"Noelle")
    , (27573,"Fern")
    , (27494,"Savanna")
    , (27415,"Shayla")
    , (27214,"Kayleigh")
    , (27203,"Fatima")
    , (27093,"Aileen")
    , (26947,"Lela")
    , (26924,"Shana")
    , (26897,"Debora")
    , (26792,"Lou")
    , (26755,"Janette")
    , (26688,"Angeline")
    , (26625,"Reese")
    , (26604,"Dorothea")
    , (26470,"Dena")
    , (26454,"Lenora")
    , (26253,"Ollie")
    , (26215,"Cherie")
    , (26143,"Dina")
    , (26092,"Brooklynn")
    , (26090,"Frankie")
    , (26043,"Delilah")
    , (25990,"Eden")
    , (25986,"Helene")
    , (25979,"Addie")
    , (25973,"Jolene")
    , (25866,"Antonia")
    , (25788,"Cierra")
    , (25721,"Haylee")
    , (25678,"Estella")
    , (25633,"Randi")
    , (25581,"Hillary")
    , (25490,"Shanna")
    , (25405,"Macy")
    , (25331,"Carissa")
    , (25268,"Cathleen")
    , (25156,"Brenna")
    , (25150,"Helena")
    , (25092,"Ora")
    , (25091,"Leanne")
    , (25043,"Joni")
    , (25027,"Shauna")
    , (24998,"Candy")
    , (24978,"Keira")
    , (24938,"May")
    , (24922,"Makenna")
    , (24916,"Delia")
    , (24602,"Angelique")
    , (24598,"Lea")
    , (24530,"Karin")
    , (24461,"Valentina")
    , (24440,"Alyson")
    , (24428,"Julianne")
    , (24319,"Amaya")
    , (24291,"Etta")
    , (24283,"Fay")
    , (24282,"Tania")
    , (24241,"Lucile")
    , (24139,"Daniella")
    , (24103,"Gwen")
    , (24051,"Francesca")
    , (23850,"Sondra")
    , (23756,"Alina")
    , (23718,"Imogene")
    , (23522,"Brielle")
    , (23495,"Cameron")
    , (23494,"Jayne")
    , (23367,"Jodie")
    , (23329,"Staci")
    , (23325,"Paris")
    , (23155,"Tiana")
    , (23080,"Ina")
    , (23018,"Kailey")
    , (22990,"Lara")
    , (22858,"Camryn")
    , (22855,"Lorna")
    , (22837,"Iva")
    , (22805,"Polly")
    , (22712,"Eugenia")
    , (22678,"Leilani")
    , (22663,"Athena")
    , (22579,"Alivia")
    , (22538,"Luz")
    , (22435,"Goldie")
    , (22401,"Cleo")
    ]

femaleNameList08 :: [(Int, Text)]
femaleNameList08 =
    [ (22388,"Phoebe")
    , (22258,"Clare")
    , (22167,"Elva")
    , (22144,"Jenifer")
    , (22109,"Taryn")
    , (22045,"Paisley")
    , (21971,"Chasity")
    , (21959,"Blanca")
    , (21927,"Jewell")
    , (21886,"Rosetta")
    , (21849,"Susanne")
    , (21760,"Trudy")
    , (21724,"Alayna")
    , (21681,"Kenya")
    , (21671,"Kiana")
    , (21562,"Lizbeth")
    , (21559,"Talia")
    , (21501,"Hayden")
    , (21498,"Heaven")
    , (21264,"Maribel")
    , (21263,"Izabella")
    , (21254,"Francis")
    , (21246,"Emilia")
    , (21182,"Julissa")
    , (21118,"Effie")
    , (21100,"Tiara")
    , (21088,"Aniyah")
    , (21072,"Tamika")
    , (21056,"Hallie")
    , (20991,"Logan")
    , (20842,"Hilary")
    , (20806,"Bettye")
    , (20804,"Ingrid")
    , (20703,"Juliet")
    , (20698,"Imani")
    , (20694,"Rosalind")
    , (20633,"Jeannine")
    , (20617,"Simone")
    , (20576,"Fiona")
    , (20520,"Glenna")
    , (20473,"Arielle")
    , (20427,"Leann")
    , (20361,"Lizzie")
    , (20301,"Ashlynn")
    , (20301,"Ericka")
    , (20298,"Paola")
    , (20240,"Mila")
    , (20223,"Lyla")
    , (20195,"Latonya")
    , (20191,"Maritza")
    , (20184,"Leola")
    , (20092,"Skyler")
    , (20084,"Elsa")
    , (20068,"Chris")
    , (20020,"Bridgette")
    , (19982,"Sienna")
    , (19947,"Bobbi")
    , (19931,"Jeanine")
    , (19928,"Audra")
    , (19879,"Elvira")
    , (19759,"Keisha")
    , (19746,"Luella")
    , (19667,"Emilee")
    , (19620,"Ola")
    , (19579,"Hadley")
    , (19527,"Jayden")
    , (19514,"Sheena")
    , (19501,"Willa")
    , (19473,"Deana")
    , (19413,"Ryan")
    , (19340,"Larissa")
    , (19309,"Kali")
    , (19262,"Lorie")
    , (19171,"Quinn")
    , (19064,"Tonia")
    , (19026,"Lexi")
    , (19000,"Jimmie")
    , (18956,"Jeri")
    , (18927,"Harmony")
    , (18804,"Harley")
    , (18781,"Angelia")
    , (18761,"Jami")
    , (18643,"Robbie")
    , (18641,"Marley")
    , (18484,"Clarice")
    , (18451,"Brynn")
    , (18428,"Willow")
    , (18364,"Margo")
    , (18362,"Ryleigh")
    , (18291,"Christi")
    , (18265,"Brianne")
    , (18260,"Carmela")
    , (18208,"James")
    , (18132,"Sidney")
    , (18126,"Greta")
    , (18059,"Aisha")
    , (18054,"Nia")
    , (17990,"India")
    , (17981,"Kaylie")
    , (17861,"Emilie")
    ]

femaleNameList09 :: [(Int, Text)]
femaleNameList09 =
    [ (17859,"Leanna")
    , (17836,"Ladonna")
    , (17819,"Dale")
    , (17801,"Marcy")
    , (17785,"Juliette")
    , (17737,"Millie")
    , (17674,"Bernadine")
    , (17613,"Viviana")
    , (17571,"Ximena")
    , (17523,"Rene")
    , (17492,"Alta")
    , (17490,"Malia")
    , (17438,"Darcy")
    , (17418,"Nell")
    , (17397,"Kamryn")
    , (17364,"Tabatha")
    , (17339,"Eve")
    , (17328,"Elaina")
    , (17287,"Kiera")
    , (17282,"Alexus")
    , (17270,"Tanisha")
    , (17206,"Michael")
    , (17118,"Terrie")
    , (17090,"Matilda")
    , (17087,"Alanna")
    , (17081,"Susana")
    , (17004,"Gale")
    , (17002,"Katlyn")
    , (16973,"Karissa")
    , (16970,"Yasmin")
    , (16924,"Lauryn")
    , (16913,"Evangeline")
    , (16903,"Ashton")
    , (16886,"Devon")
    , (16883,"Nelda")
    , (16882,"Amie")
    , (16876,"Selma")
    , (16868,"Rhoda")
    , (16850,"Cadence")
    , (16777,"Noemi")
    , (16756,"Perla")
    , (16749,"Dorthy")
    , (16714,"Baylee")
    , (16685,"Lupe")
    , (16674,"Christian")
    , (16622,"Bryanna")
    , (16594,"Kelsie")
    , (16573,"Madalyn")
    , (16458,"Latisha")
    , (16458,"Lenore")
    , (16361,"Colette")
    , (16230,"Presley")
    , (16222,"Noreen")
    , (16220,"Kiley")
    , (16220,"Ruthie")
    , (16150,"Jayda")
    , (16081,"Lacy")
    , (16012,"Tatum")
    , (15971,"Adelaide")
    , (15928,"Emely")
    , (15835,"Precious")
    , (15809,"Araceli")
    , (15769,"Kassidy")
    , (15731,"Esperanza")
    , (15709,"Maddison")
    , (15679,"John")
    , (15675,"Melisa")
    , (15586,"Claudette")
    , (15549,"Rosalyn")
    , (15546,"Kaylin")
    , (15546,"Charlie")
    , (15526,"Nayeli")
    , (15467,"Silvia")
    , (15410,"Mara")
    , (15341,"Kyleigh")
    , (15267,"Mikaela")
    , (15260,"Dulce")
    , (15228,"Elnora")
    , (15189,"Luna")
    , (15132,"Saundra")
    , (15114,"Robert")
    , (15091,"Maura")
    , (15077,"Harriett")
    , (15077,"Mavis")
    , (15013,"Cortney")
    , (14967,"Frieda")
    , (14935,"Lorrie")
    , (14912,"Annmarie")
    , (14904,"Katy")
    , (14841,"Skye")
    , (14767,"Gay")
    , (14718,"Beatriz")
    , (14684,"Devin")
    , (14678,"Elyse")
    , (14660,"Ila")
    , (14644,"Nola")
    , (14627,"Carmella")
    , (14617,"Elinor")
    , (14617,"Chandra")
    , (14610,"Malinda")
    ]


maleFirstName :: FGen SingleWord
maleFirstName = frequency $ map (second (return . SingleWord)) maleNameList


------------------------------------------------------------------------------
-- | List of the 1000 most common U.S. male names and the number of people
-- with that name.  This is from a dataset of 302037244 names from the Social
-- Security Adminisatration between 1910 and 2015.
maleNameList :: [(Int, Text)]
maleNameList = maleNameList00
            ++ maleNameList01
            ++ maleNameList02
            ++ maleNameList03
            ++ maleNameList04
            ++ maleNameList05
            ++ maleNameList06
            ++ maleNameList07
            ++ maleNameList08
            ++ maleNameList09

maleNameList00 :: [(Int, Text)]
maleNameList00 =
    [ (4954037,"James")
    , (4840467,"John")
    , (4716978,"Robert")
    , (4310511,"Michael")
    , (3845199,"William")
    , (3566154,"David")
    , (2532760,"Richard")
    , (2491293,"Joseph")
    , (2251908,"Charles")
    , (2223640,"Thomas")
    , (2001078,"Christopher")
    , (1866293,"Daniel")
    , (1561248,"Matthew")
    , (1404066,"Anthony")
    , (1402101,"Donald")
    , (1357937,"Paul")
    , (1341830,"Mark")
    , (1322761,"George")
    , (1273341,"Steven")
    , (1262387,"Kenneth")
    , (1247633,"Andrew")
    , (1213917,"Edward")
    , (1181368,"Joshua")
    , (1158944,"Brian")
    , (1157267,"Kevin")
    , (1074521,"Ronald")
    , (1059934,"Timothy")
    , (1016641,"Jason")
    , (970378,"Jeffrey")
    , (907427,"Ryan")
    , (896997,"Gary")
    , (880959,"Jacob")
    , (879024,"Nicholas")
    , (866465,"Eric")
    , (847268,"Stephen")
    , (818880,"Frank")
    , (817906,"Jonathan")
    , (801488,"Larry")
    , (766349,"Scott")
    , (763019,"Justin")
    , (746352,"Raymond")
    , (744587,"Brandon")
    , (703106,"Samuel")
    , (702752,"Gregory")
    , (691499,"Benjamin")
    , (660152,"Patrick")
    , (650943,"Jack")
    , (626604,"Alexander")
    , (611704,"Dennis")
    , (605577,"Jerry")
    , (589855,"Henry")
    , (573357,"Tyler")
    , (559365,"Walter")
    , (557315,"Peter")
    , (556299,"Aaron")
    , (553409,"Douglas")
    , (544224,"Jose")
    , (534139,"Adam")
    , (525297,"Harold")
    , (521578,"Zachary")
    , (521387,"Nathan")
    , (477652,"Carl")
    , (475217,"Arthur")
    , (471737,"Kyle")
    , (441995,"Gerald")
    , (441316,"Albert")
    , (439984,"Lawrence")
    , (434800,"Roger")
    , (431309,"Keith")
    , (428393,"Jeremy")
    , (422729,"Joe")
    , (419008,"Terry")
    , (412285,"Sean")
    , (411515,"Willie")
    , (396076,"Christian")
    , (394713,"Jesse")
    , (392088,"Austin")
    , (389255,"Ralph")
    , (384225,"Ethan")
    , (379009,"Billy")
    , (377119,"Bruce")
    , (374623,"Roy")
    , (372552,"Bryan")
    , (363707,"Louis")
    , (362319,"Eugene")
    , (355992,"Harry")
    , (355386,"Jordan")
    , (347534,"Wayne")
    , (341813,"Russell")
    , (340961,"Dylan")
    , (339390,"Alan")
    , (333747,"Juan")
    , (332586,"Noah")
    , (329615,"Philip")
    , (324932,"Randy")
    , (324829,"Vincent")
    , (323886,"Howard")
    , (314693,"Gabriel")
    , (309940,"Bobby")
    , (305881,"Johnny")
    ]

maleNameList01 :: [(Int, Text)]
maleNameList01 =
    [ (303507,"Victor")
    , (301431,"Phillip")
    , (299161,"Shawn")
    , (297953,"Bradley")
    , (297290,"Fred")
    , (296411,"Travis")
    , (295413,"Craig")
    , (291870,"Martin")
    , (291581,"Logan")
    , (288496,"Stanley")
    , (282114,"Jimmy")
    , (279104,"Danny")
    , (278678,"Todd")
    , (277725,"Cody")
    , (277676,"Leonard")
    , (275854,"Carlos")
    , (275127,"Ernest")
    , (273388,"Dale")
    , (266454,"Francis")
    , (265307,"Clarence")
    , (263604,"Earl")
    , (259966,"Luis")
    , (258610,"Caleb")
    , (257643,"Alex")
    , (257447,"Allen")
    , (257097,"Joel")
    , (256618,"Cameron")
    , (252668,"Nathaniel")
    , (251916,"Curtis")
    , (249155,"Elijah")
    , (247590,"Isaac")
    , (247266,"Evan")
    , (245085,"Frederick")
    , (243359,"Marvin")
    , (243237,"Tony")
    , (242749,"Norman")
    , (241843,"Rodney")
    , (240403,"Glenn")
    , (237870,"Luke")
    , (237314,"Mason")
    , (237112,"Chad")
    , (236185,"Antonio")
    , (234456,"Melvin")
    , (234182,"Steve")
    , (226375,"Jeffery")
    , (225913,"Edwin")
    , (224920,"Derek")
    , (221954,"Alfred")
    , (220883,"Marcus")
    , (217989,"Ricky")
    , (216612,"Jesus")
    , (214740,"Lee")
    , (214301,"Adrian")
    , (213426,"Angel")
    , (213045,"Theodore")
    , (211657,"Lucas")
    , (211408,"Hunter")
    , (210021,"Ian")
    , (207966,"Herbert")
    , (205723,"Troy")
    , (202333,"Dustin")
    , (201919,"Jackson")
    , (199757,"Wesley")
    , (198265,"Eddie")
    , (197474,"Mike")
    , (195732,"Jared")
    , (193653,"Randall")
    , (189597,"Connor")
    , (189198,"Calvin")
    , (188943,"Isaiah")
    , (188586,"Bernard")
    , (188375,"Ray")
    , (187132,"Leroy")
    , (184664,"Shane")
    , (182370,"Jay")
    , (181524,"Julian")
    , (180537,"Jayden")
    , (178308,"Corey")
    , (178093,"Ronnie")
    , (176888,"Barry")
    , (176118,"Clifford")
    , (175196,"Oscar")
    , (174036,"Jeremiah")
    , (173467,"Manuel")
    , (171760,"Leo")
    , (171510,"Tommy")
    , (170893,"Aiden")
    , (166903,"Warren")
    , (166708,"Miguel")
    , (166355,"Dean")
    , (163921,"Blake")
    , (163160,"Jon")
    , (161585,"Don")
    , (160391,"Gavin")
    , (156964,"Mitchell")
    , (155305,"Brett")
    , (155280,"Darrell")
    , (154457,"Seth")
    , (154318,"Jerome")
    , (154267,"Bill")
    ]

maleNameList02 :: [(Int, Text)]
maleNameList02 =
    [ (154175,"Liam")
    , (153323,"Leon")
    , (152576,"Trevor")
    , (152065,"Owen")
    , (149839,"Lloyd")
    , (149810,"Micheal")
    , (149429,"Alvin")
    , (148750,"Chase")
    , (148536,"Dominic")
    , (147858,"Erik")
    , (146713,"Gordon")
    , (146469,"Devin")
    , (140623,"Jim")
    , (139072,"Floyd")
    , (138681,"Mario")
    , (138653,"Derrick")
    , (138459,"Vernon")
    , (138400,"Charlie")
    , (138014,"Chris")
    , (137026,"Edgar")
    , (135949,"Brent")
    , (135815,"Marc")
    , (135668,"Landon")
    , (135334,"Max")
    , (134615,"Lewis")
    , (133606,"Ricardo")
    , (127899,"Franklin")
    , (126791,"Clyde")
    , (126520,"Maurice")
    , (125995,"Francisco")
    , (125372,"Tom")
    , (124944,"Alejandro")
    , (124343,"Carter")
    , (123982,"Wyatt")
    , (123900,"Jorge")
    , (123658,"Garrett")
    , (123254,"Cory")
    , (123147,"Cole")
    , (122180,"Clayton")
    , (121797,"Gene")
    , (120787,"Gilbert")
    , (120775,"Sebastian")
    , (119199,"Glen")
    , (119043,"Ivan")
    , (119012,"Herman")
    , (118723,"Xavier")
    , (117971,"Lester")
    , (117061,"Levi")
    , (117036,"Colin")
    , (116586,"Oliver")
    , (115959,"Andre")
    , (114441,"Jeff")
    , (112820,"Grant")
    , (112307,"Jake")
    , (110759,"Duane")
    , (108804,"Spencer")
    , (107864,"Elmer")
    , (107371,"Chester")
    , (107208,"Milton")
    , (106254,"Jimmie")
    , (106234,"Casey")
    , (106155,"Harvey")
    , (104936,"Reginald")
    , (104426,"Colton")
    , (104333,"Ruben")
    , (104226,"Taylor")
    , (103879,"Leslie")
    , (103469,"Aidan")
    , (103161,"Bryce")
    , (103136,"Sam")
    , (103122,"Roberto")
    , (102123,"Preston")
    , (102046,"Brayden")
    , (100517,"Tristan")
    , (99876,"Lance")
    , (99304,"Darren")
    , (98856,"Jessie")
    , (97927,"Dan")
    , (97554,"Eduardo")
    , (97003,"Neil")
    , (96663,"Arnold")
    , (96203,"Cecil")
    , (95698,"Hector")
    , (95407,"Diego")
    , (95256,"Eli")
    , (94169,"Karl")
    , (93108,"Johnnie")
    , (90992,"Javier")
    , (90632,"Clinton")
    , (90065,"Roland")
    , (89654,"Fernando")
    , (88834,"Allan")
    , (88406,"Johnathan")
    , (88339,"Carson")
    , (88257,"Bob")
    , (88235,"Hayden")
    , (88100,"Darryl")
    , (88012,"Omar")
    , (86969,"Everett")
    , (86875,"Parker")
    ]

maleNameList03 :: [(Int, Text)]
maleNameList03 =
    [ (86766,"Lonnie")
    , (86683,"Tanner")
    , (85747,"Brendan")
    , (84624,"Riley")
    , (83597,"Josiah")
    , (82381,"Dakota")
    , (82321,"Marshall")
    , (82051,"Pedro")
    , (81636,"Jamie")
    , (81491,"Kurt")
    , (81314,"Andy")
    , (80726,"Micah")
    , (80186,"Brady")
    , (80089,"Brad")
    , (79796,"Raul")
    , (78843,"Guy")
    , (78776,"Nicolas")
    , (78768,"Maxwell")
    , (78464,"Tim")
    , (78295,"Nolan")
    , (78057,"Rick")
    , (77472,"Kelly")
    , (76508,"Abraham")
    , (76461,"Claude")
    , (75931,"Andres")
    , (75090,"Tyrone")
    , (74754,"Greg")
    , (74585,"Jackie")
    , (74494,"Dalton")
    , (74353,"Ross")
    , (74186,"Byron")
    , (73721,"Damian")
    , (73488,"Sidney")
    , (73434,"Wallace")
    , (73050,"Dwight")
    , (71674,"Rafael")
    , (71481,"Dwayne")
    , (70875,"Sergio")
    , (70531,"Collin")
    , (70360,"Angelo")
    , (69806,"Ted")
    , (69653,"Hugh")
    , (69396,"Kaleb")
    , (69316,"Cooper")
    , (69275,"Drew")
    , (69197,"Willard")
    , (69166,"Nelson")
    , (68857,"Ben")
    , (68535,"Mathew")
    , (68464,"Jaden")
    , (68381,"Ramon")
    , (67859,"Freddie")
    , (67813,"Armando")
    , (67472,"Perry")
    , (67254,"Cesar")
    , (67012,"Terrence")
    , (66553,"Devon")
    , (66520,"Shaun")
    , (66472,"Julius")
    , (64933,"Emmanuel")
    , (64753,"Marco")
    , (64555,"Miles")
    , (64546,"Terrance")
    , (64520,"Erick")
    , (63792,"Kent")
    , (63464,"Stuart")
    , (63382,"Kirk")
    , (63364,"Jaime")
    , (63259,"Marion")
    , (62902,"Virgil")
    , (62678,"Clifton")
    , (62225,"Wade")
    , (62054,"Morris")
    , (61468,"Jonathon")
    , (61109,"Elias")
    , (60284,"Ayden")
    , (59899,"Ashton")
    , (59857,"Harrison")
    , (59286,"Dillon")
    , (58903,"Brody")
    , (58792,"Kristopher")
    , (58667,"Daryl")
    , (58642,"Alexis")
    , (58319,"Rickey")
    , (58286,"Felix")
    , (58246,"Cristian")
    , (58206,"Giovanni")
    , (58076,"Damon")
    , (57289,"Fredrick")
    , (56735,"Dominick")
    , (56488,"Tracy")
    , (56170,"Donnie")
    , (55951,"Dave")
    , (55595,"Alberto")
    , (55360,"Julio")
    , (55117,"Lorenzo")
    , (54622,"Malcolm")
    , (54539,"Caden")
    , (54416,"Jonah")
    , (54374,"Jaxon")
    ]

maleNameList04 :: [(Int, Text)]
maleNameList04 =
    [ (54310,"Kaden")
    , (53538,"Luther")
    , (53524,"Dallas")
    , (53421,"Gage")
    , (52972,"Gerard")
    , (52501,"Enrique")
    , (52124,"Israel")
    , (51789,"Salvatore")
    , (51775,"Trenton")
    , (51742,"Roman")
    , (51684,"Leonardo")
    , (51551,"Rex")
    , (51211,"Damien")
    , (51097,"Lyle")
    , (50981,"Grayson")
    , (50708,"Jace")
    , (50412,"Geoffrey")
    , (50385,"Earnest")
    , (50210,"Hubert")
    , (49724,"Alfredo")
    , (49448,"Arturo")
    , (49447,"Homer")
    , (49333,"Donovan")
    , (49241,"Wilbur")
    , (49177,"Otis")
    , (48930,"Simon")
    , (48791,"Neal")
    , (48684,"Dana")
    , (48667,"Conner")
    , (48387,"Wendell")
    , (48113,"Shannon")
    , (47691,"Bryson")
    , (47633,"Joey")
    , (47598,"Lynn")
    , (47441,"Gerardo")
    , (47037,"Colby")
    , (46715,"Alec")
    , (46704,"Trent")
    , (46522,"Darius")
    , (46494,"Santiago")
    , (46277,"Kerry")
    , (46171,"Rudolph")
    , (46171,"Kenny")
    , (46167,"Kelvin")
    , (45796,"Bennie")
    , (45322,"Leland")
    , (44954,"Horace")
    , (44735,"Avery")
    , (44631,"Marcos")
    , (44256,"Randolph")
    , (44203,"Bryant")
    , (44084,"Rene")
    , (43882,"Garry")
    , (43543,"Josue")
    , (43542,"Carlton")
    , (43333,"Willis")
    , (43087,"Peyton")
    , (42676,"Emanuel")
    , (42589,"Nick")
    , (42526,"Edmund")
    , (42439,"Salvador")
    , (42006,"Chance")
    , (41863,"Ira")
    , (41839,"Rudy")
    , (41706,"Benny")
    , (41650,"Orlando")
    , (41350,"Delbert")
    , (41064,"Ty")
    , (40973,"Roderick")
    , (40802,"Braden")
    , (40545,"Abel")
    , (40308,"Forrest")
    , (40187,"Loren")
    , (39941,"Alton")
    , (39940,"Malik")
    , (39901,"Robin")
    , (39644,"Archie")
    , (39563,"Pablo")
    , (39510,"Hudson")
    , (39305,"Grady")
    , (38809,"Noel")
    , (38804,"Myron")
    , (38784,"Ernesto")
    , (38743,"Jermaine")
    , (38361,"Emmett")
    , (38357,"Malachi")
    , (38328,"Wilson")
    , (37938,"Dante")
    , (37932,"Sammy")
    , (37619,"Tyson")
    , (37527,"Kayden")
    , (37238,"Zane")
    , (36707,"Clark")
    , (36673,"Brock")
    , (36580,"Braxton")
    , (36293,"Pete")
    , (36105,"Lowell")
    , (35981,"Frankie")
    , (35883,"Sylvester")
    , (35796,"Irving")
    ]

maleNameList05 :: [(Int, Text)]
maleNameList05 =
    [ (35714,"Skyler")
    , (35698,"Cedric")
    , (35656,"Morgan")
    , (35433,"Asher")
    , (35426,"Junior")
    , (34966,"Wilbert")
    , (34952,"Lincoln")
    , (34704,"Trey")
    , (34521,"Camden")
    , (34429,"Jalen")
    , (34286,"Woodrow")
    , (34269,"Quentin")
    , (34248,"Alfonso")
    , (34186,"Elliott")
    , (33825,"Nickolas")
    , (33634,"Gustavo")
    , (33519,"Alonzo")
    , (33394,"Fabian")
    , (33392,"Saul")
    , (33294,"Ryder")
    , (33119,"Gregg")
    , (32999,"Easton")
    , (32962,"Graham")
    , (32892,"Emilio")
    , (32679,"Roosevelt")
    , (32670,"Ron")
    , (32507,"Sherman")
    , (32489,"Tucker")
    , (32486,"Laurence")
    , (32342,"Ellis")
    , (32330,"Griffin")
    , (32086,"Kim")
    , (32037,"Ervin")
    , (32005,"Irvin")
    , (31581,"Myles")
    , (31577,"Weston")
    , (31509,"Ismael")
    , (31382,"Mateo")
    , (31159,"Demetrius")
    , (31159,"Terrell")
    , (31084,"Harley")
    , (31018,"Sawyer")
    , (30929,"Clay")
    , (30845,"Elliot")
    , (30821,"Carroll")
    , (30797,"Bentley")
    , (30605,"Jaxson")
    , (30431,"Silas")
    , (30332,"Sheldon")
    , (30304,"Ezra")
    , (30232,"Moses")
    , (29963,"Jaylen")
    , (29855,"Keegan")
    , (29694,"Lane")
    , (29572,"Terence")
    , (29564,"Darin")
    , (29477,"Jasper")
    , (29449,"Rodolfo")
    , (29381,"Tommie")
    , (29358,"August")
    , (29330,"Drake")
    , (29244,"Mack")
    , (29014,"Ezekiel")
    , (28919,"Cornelius")
    , (28899,"Dawson")
    , (28770,"Jamal")
    , (28683,"Orville")
    , (28604,"Corbin")
    , (28602,"Kendall")
    , (28564,"Toby")
    , (28499,"Chandler")
    , (28381,"Lamar")
    , (28252,"Cayden")
    , (28251,"Beau")
    , (28237,"Rufus")
    , (28195,"Marty")
    , (28189,"Ken")
    , (28138,"Kaiden")
    , (27961,"Jody")
    , (27916,"Brennan")
    , (27868,"Jayson")
    , (27814,"Zackary")
    , (27791,"Kai")
    , (27774,"Desmond")
    , (27613,"Billie")
    , (27598,"Jakob")
    , (27571,"Axel")
    , (27183,"Kameron")
    , (27165,"Jude")
    , (27156,"Clint")
    , (27039,"Teddy")
    , (27023,"Zachery")
    , (26962,"Elbert")
    , (26905,"Dane")
    , (26823,"Conrad")
    , (26806,"Dewey")
    , (26699,"Bret")
    , (26665,"Doyle")
    , (26647,"Darrin")
    , (26600,"Lukas")
    ]

maleNameList06 :: [(Int, Text)]
maleNameList06 =
    [ (26570,"Bradford")
    , (26520,"Guillermo")
    , (26493,"Bennett")
    , (26489,"Dexter")
    , (26294,"Esteban")
    , (26047,"Quinn")
    , (25949,"Felipe")
    , (25638,"Kyler")
    , (25566,"Hugo")
    , (25449,"Dick")
    , (25288,"Merle")
    , (25281,"Darrel")
    , (25278,"Marlon")
    , (25277,"Blaine")
    , (25255,"Randal")
    , (25019,"Deandre")
    , (24870,"Heath")
    , (24792,"Will")
    , (24786,"Branden")
    , (24711,"Gilberto")
    , (24573,"Stewart")
    , (24512,"Aubrey")
    , (24456,"Reid")
    , (24363,"Jaiden")
    , (24303,"Amos")
    , (24292,"Quinton")
    , (24248,"Solomon")
    , (24158,"Darnell")
    , (23864,"Declan")
    , (23636,"Sterling")
    , (23620,"Maddox")
    , (23602,"Bert")
    , (23496,"Kendrick")
    , (23367,"Amir")
    , (23345,"Zachariah")
    , (23339,"Lionel")
    , (23311,"Cade")
    , (23265,"Moises")
    , (23217,"Wilfred")
    , (23164,"Antoine")
    , (22975,"Jarrod")
    , (22936,"Rylan")
    , (22896,"Emil")
    , (22882,"Joaquin")
    , (22791,"Adan")
    , (22768,"Percy")
    , (22714,"Pat")
    , (22659,"Rocco")
    , (22590,"Reed")
    , (22570,"Brenden")
    , (22400,"Tomas")
    , (22368,"Johnathon")
    , (22178,"Timmy")
    , (22168,"Dewayne")
    , (22058,"Guadalupe")
    , (21943,"Davis")
    , (21924,"Mickey")
    , (21852,"Stephan")
    , (21713,"Zion")
    , (21677,"Rocky")
    , (21503,"Reuben")
    , (21444,"Jerald")
    , (21424,"Ramiro")
    , (21410,"Jameson")
    , (21403,"Louie")
    , (21280,"Rogelio")
    , (21261,"Ali")
    , (21216,"Freddy")
    , (20940,"Van")
    , (20856,"Landen")
    , (20835,"Boyd")
    , (20689,"Payton")
    , (20664,"Marquis")
    , (20539,"Rory")
    , (20435,"Eldon")
    , (20292,"Royce")
    , (20024,"Rodrigo")
    , (19971,"Xander")
    , (19927,"Doug")
    , (19870,"Dominique")
    , (19834,"Cary")
    , (19790,"Kody")
    , (19737,"Rolando")
    , (19716,"Greyson")
    , (19637,"Winston")
    , (19496,"Lamont")
    , (19398,"Quincy")
    , (19342,"Isiah")
    , (19315,"Otto")
    , (19216,"Maximus")
    , (19083,"Garland")
    , (18952,"Darwin")
    , (18902,"Jayce")
    , (18711,"Jarrett")
    , (18410,"Vance")
    , (18340,"Grover")
    , (18322,"Conor")
    , (18313,"Anderson")
    , (18176,"Luca")
    , (18079,"Courtney")
    ]

maleNameList07 :: [(Int, Text)]
maleNameList07 =
    [ (18075,"Stacy")
    , (18051,"Cruz")
    , (17958,"Matt")
    , (17953,"Noe")
    , (17948,"Edmond")
    , (17931,"Mauricio")
    , (17918,"Buddy")
    , (17852,"Tristen")
    , (17850,"Loyd")
    , (17730,"Thaddeus")
    , (17680,"Jean")
    , (17478,"Nikolas")
    , (17392,"Jan")
    , (17217,"Sammie")
    , (17182,"Rodger")
    , (17182,"Monte")
    , (17099,"Jonas")
    , (17085,"Harlan")
    , (17060,"Bailey")
    , (16940,"Robbie")
    , (16920,"Holden")
    , (16797,"Emiliano")
    , (16789,"Kingston")
    , (16784,"Keaton")
    , (16748,"Cleveland")
    , (16709,"Reynaldo")
    , (16675,"Walker")
    , (16623,"Brendon")
    , (16533,"Issac")
    , (16480,"Norbert")
    , (16474,"Gael")
    , (16402,"Zander")
    , (16268,"Brooks")
    , (16246,"Jess")
    , (16141,"Aden")
    , (16045,"Dorian")
    , (16032,"Anton")
    , (15979,"Nathanael")
    , (15936,"Burton")
    , (15873,"Murray")
    , (15837,"Johnie")
    , (15632,"Vicente")
    , (15474,"Elwood")
    , (15446,"Marlin")
    , (15446,"Ed")
    , (15424,"Derick")
    , (15376,"Kristian")
    , (15337,"Leonel")
    , (15267,"Elton")
    , (15228,"Phil")
    , (15218,"Denis")
    , (15172,"Stefan")
    , (15153,"Jase")
    , (15096,"Scotty")
    , (15049,"Ryker")
    , (15042,"Bobbie")
    , (15011,"Zackery")
    , (14995,"Brantley")
    , (14986,"Ignacio")
    , (14973,"Efrain")
    , (14917,"Jefferson")
    , (14771,"Skylar")
    , (14737,"Erwin")
    , (14716,"Emerson")
    , (14688,"Caiden")
    , (14649,"Elvin")
    , (14617,"Chuck")
    , (14434,"Roscoe")
    , (14255,"Rusty")
    , (14241,"Javon")
    , (14182,"Kurtis")
    , (14166,"Ariel")
    , (14165,"Kobe")
    , (14130,"Khalil")
    , (14117,"Justice")
    , (14116,"Ahmad")
    , (14073,"King")
    , (13804,"Humberto")
    , (13797,"Dion")
    , (13625,"Vaughn")
    , (13509,"Carmen")
    , (13491,"Damion")
    , (13470,"Duncan")
    , (13430,"Judah")
    , (13365,"Cash")
    , (13356,"Santos")
    , (13340,"Rashad")
    , (13335,"Uriel")
    , (13313,"Tate")
    , (13273,"Romeo")
    , (13217,"Aron")
    , (13200,"Keenan")
    , (13194,"Rickie")
    , (13168,"Amari")
    , (13138,"Milo")
    , (13131,"Jamar")
    , (13093,"Raphael")
    , (13074,"Reece")
    , (13039,"Braylon")
    , (13033,"Titus")
    ]

maleNameList08 :: [(Int, Text)]
maleNameList08 =
    [ (13026,"Kade")
    , (12991,"Rowan")
    , (12982,"Jarvis")
    , (12972,"Waylon")
    , (12906,"Cyrus")
    , (12874,"Finn")
    , (12861,"Donte")
    , (12824,"Adolfo")
    , (12764,"Bart")
    , (12752,"Jamison")
    , (12732,"Deshawn")
    , (12722,"Pierre")
    , (12710,"Tobias")
    , (12676,"Tyrell")
    , (12667,"Charley")
    , (12650,"Kareem")
    , (12647,"Curt")
    , (12503,"Brayan")
    , (12408,"Elvis")
    , (12372,"Adolph")
    , (12359,"Kermit")
    , (12297,"Thurman")
    , (12288,"Aldo")
    , (12258,"Darian")
    , (12256,"Ulysses")
    , (12250,"Carey")
    , (12214,"Marcel")
    , (12180,"Kellen")
    , (12152,"Gunner")
    , (12147,"Alvaro")
    , (12066,"Colten")
    , (12026,"Mohamed")
    , (11943,"Trevon")
    , (11932,"Zayden")
    , (11914,"Ned")
    , (11869,"Hal")
    , (11793,"Paxton")
    , (11787,"Ernie")
    , (11726,"Jeffry")
    , (11705,"Agustin")
    , (11656,"Vito")
    , (11646,"Camron")
    , (11625,"Al")
    , (11601,"Osvaldo")
    , (11586,"Bruno")
    , (11559,"Millard")
    , (11542,"Norris")
    , (11523,"Braeden")
    , (11520,"Colt")
    , (11475,"Irwin")
    , (11436,"Coy")
    , (11397,"Shelby")
    , (11351,"Nehemiah")
    , (11336,"Ashley")
    , (11316,"Maximilian")
    , (11251,"Braydon")
    , (11206,"Josh")
    , (11191,"Seymour")
    , (11153,"Alphonso")
    , (11072,"River")
    , (11057,"Reese")
    , (11038,"Kory")
    , (11030,"Deon")
    , (10994,"Rhett")
    , (10980,"Maverick")
    , (10970,"Demarcus")
    , (10951,"Gus")
    , (10944,"Barrett")
    , (10888,"Armand")
    , (10878,"Jordon")
    , (10860,"Barney")
    , (10859,"Odell")
    , (10858,"Scot")
    , (10842,"Moshe")
    , (10801,"Jarred")
    , (10789,"Donnell")
    , (10786,"Wiley")
    , (10776,"Monty")
    , (10772,"Mohammad")
    , (10769,"Bryon")
    , (10752,"Domingo")
    , (10749,"Kris")
    , (10744,"Devan")
    , (10696,"Russel")
    , (10689,"Emory")
    , (10637,"Galen")
    , (10630,"Sonny")
    , (10619,"Ahmed")
    , (10585,"Denny")
    , (10571,"Pierce")
    , (10564,"Isaias")
    , (10539,"Benito")
    , (10538,"Coleman")
    , (10530,"Stacey")
    , (10505,"Brenton")
    , (10498,"Davon")
    , (10485,"Carmine")
    , (10481,"Tyree")
    , (10454,"Quintin")
    , (10446,"Carlo")
    ]

maleNameList09 :: [(Int, Text)]
maleNameList09 =
    [ (10405,"Ezequiel")
    , (10396,"Ronny")
    , (10379,"Maynard")
    , (10370,"Abram")
    , (10350,"Laverne")
    , (10336,"Chadwick")
    , (10319,"Gerry")
    , (10281,"Wilmer")
    , (10193,"Sanford")
    , (10129,"Phoenix")
    , (10124,"Merlin")
    , (10122,"Emery")
    , (10108,"Houston")
    , (10099,"Brice")
    , (10088,"Maximiliano")
    , (10062,"Ollie")
    , (10047,"Monroe")
    , (10032,"Gunnar")
    , (10024,"Antwan")
    , (9973,"Jax")
    , (9962,"Mohammed")
    , (9939,"Prince")
    , (9916,"Markus")
    , (9896,"Ari")
    , (9886,"Jett")
    , (9861,"Joesph")
    , (9828,"Porter")
    , (9813,"Kolton")
    , (9735,"Davion")
    , (9669,"Linwood")
    , (9666,"Orion")
    , (9634,"Mary")
    , (9590,"Denver")
    , (9518,"Cohen")
    , (9492,"Delmar")
    , (9458,"Stevie")
    , (9452,"Garret")
    , (9426,"Tevin")
    , (9412,"Devonte")
    , (9382,"Cullen")
    , (9352,"Weldon")
    , (9343,"Triston")
    , (9296,"Karter")
    , (9294,"Jarod")
    , (9293,"Beckett")
    , (9281,"Jamari")
    , (9276,"Karson")
    , (9237,"Blair")
    , (9202,"Truman")
    , (9191,"Gale")
    , (9184,"Harris")
    , (9155,"Morton")
    , (9093,"Donny")
    , (9075,"Kieran")
    , (9034,"Yahir")
    , (9034,"Matteo")
    , (9031,"Nasir")
    , (8965,"Frederic")
    , (8932,"Deangelo")
    , (8909,"Dayton")
    , (8899,"Hollis")
    , (8898,"Muhammad")
    , (8886,"Major")
    , (8873,"Clair")
    , (8800,"Rigoberto")
    , (8754,"Asa")
    , (8727,"Izaiah")
    , (8711,"Kirby")
    , (8700,"Ward")
    , (8693,"Hans")
    , (8692,"Nigel")
    , (8671,"Jaquan")
    , (8666,"Jamel")
    , (8643,"Gideon")
    , (8636,"Augustus")
    , (8562,"Kasey")
    , (8521,"Iker")
    , (8472,"Mekhi")
    , (8417,"Gino")
    , (8395,"Trace")
    , (8347,"Ibrahim")
    , (8328,"Forest")
    , (8304,"Eddy")
    , (8304,"Ulises")
    , (8285,"Jaylin")
    , (8285,"Brycen")
    , (8261,"Kane")
    , (8251,"Jaron")
    , (8247,"Fidel")
    , (8236,"Pasquale")
    , (8192,"Kolby")
    , (8191,"Octavio")
    , (8181,"Marquise")
    , (8156,"Clement")
    , (8105,"Augustine")
    , (8089,"Buford")
    , (8079,"Korey")
    , (8025,"Addison")
    , (7999,"Remington")
    , (7980,"Wilfredo")
    ]


lastName :: FGen SingleWord
lastName = frequency $ map (second (return . SingleWord)) lastNameList


------------------------------------------------------------------------------
-- | List of the 1000 most common U.S. surnames and the number of people with
-- that name.  This is from a dataset of 269762087 names from the 2000 U.S.
-- Census.
lastNameList :: [(Int, Text)]
lastNameList = lastNameList00
            ++ lastNameList01
            ++ lastNameList02
            ++ lastNameList03
            ++ lastNameList04
            ++ lastNameList05
            ++ lastNameList06
            ++ lastNameList07
            ++ lastNameList08
            ++ lastNameList09

lastNameList00 :: [(Int, Text)]
lastNameList00 =
    [ (2376206,"Smith")
    , (1857160,"Johnson")
    , (1534042,"Williams")
    , (1380145,"Brown")
    , (1362755,"Jones")
    , (1127803,"Miller")
    , (1072335,"Davis")
    , (858289,"Garcia")
    , (804240,"Rodriguez")
    , (783051,"Wilson")
    , (775072,"Martinez")
    , (762394,"Anderson")
    , (720370,"Taylor")
    , (710696,"Thomas")
    , (706372,"Hernandez")
    , (698671,"Moore")
    , (672711,"Martin")
    , (666125,"Jackson")
    , (644368,"Thompson")
    , (639515,"White")
    , (621536,"Lopez")
    , (605860,"Lee")
    , (597718,"Gonzalez")
    , (593542,"Harris")
    , (548369,"Clark")
    , (509930,"Lewis")
    , (503028,"Robinson")
    , (501307,"Walker")
    , (488521,"Perez")
    , (473568,"Hall")
    , (465948,"Young")
    , (463368,"Allen")
    , (441242,"Sanchez")
    , (440367,"Wright")
    , (438986,"King")
    , (420091,"Scott")
    , (413477,"Green")
    , (413351,"Baker")
    , (413086,"Adams")
    , (412236,"Nelson")
    , (411770,"Hill")
    , (388987,"Ramirez")
    , (371953,"Campbell")
    , (367433,"Mitchell")
    , (366215,"Roberts")
    , (362548,"Carter")
    , (351848,"Phillips")
    , (342237,"Evans")
    , (335663,"Turner")
    , (325169,"Torres")
    , (324246,"Parker")
    , (317848,"Collins")
    , (317070,"Edwards")
    , (312899,"Stewart")
    , (312615,"Flores")
    , (311754,"Morris")
    , (310125,"Nguyen")
    , (300501,"Murphy")
    , (299463,"Rivera")
    , (294795,"Cook")
    , (294403,"Rogers")
    , (276400,"Morgan")
    , (275041,"Peterson")
    , (270097,"Cooper")
    , (267443,"Reed")
    , (265916,"Bailey")
    , (264752,"Bell")
    , (263590,"Gomez")
    , (260385,"Kelly")
    , (254779,"Howard")
    , (254121,"Ward")
    , (253771,"Cox")
    , (251772,"Diaz")
    , (249533,"Richardson")
    , (247299,"Wood")
    , (242432,"Watson")
    , (240751,"Brooks")
    , (239055,"Bennett")
    , (236713,"Gray")
    , (233224,"James")
    , (232511,"Reyes")
    , (231065,"Cruz")
    , (229390,"Hughes")
    , (228756,"Price")
    , (224824,"Myers")
    , (223494,"Long")
    , (221040,"Foster")
    , (220902,"Sanders")
    , (219961,"Ross")
    , (217642,"Morales")
    , (216553,"Powell")
    , (215640,"Sullivan")
    , (215432,"Russell")
    , (214683,"Ortiz")
    , (213737,"Jenkins")
    , (212905,"Gutierrez")
    , (212644,"Perry")
    , (210879,"Butler")
    , (210426,"Barnes")
    , (210279,"Fisher")
    ]

lastNameList01 :: [(Int, Text)]
lastNameList01 =
    [ (210094,"Henderson")
    , (208624,"Coleman")
    , (201650,"Simmons")
    , (198557,"Patterson")
    , (197212,"Jordan")
    , (195598,"Reynolds")
    , (194331,"Hamilton")
    , (194074,"Graham")
    , (194067,"Kim")
    , (193934,"Gonzales")
    , (193443,"Alexander")
    , (193096,"Ramos")
    , (190760,"Wallace")
    , (190636,"Griffin")
    , (188464,"West")
    , (187793,"Cole")
    , (187473,"Hayes")
    , (185865,"Chavez")
    , (184420,"Gibson")
    , (183761,"Bryant")
    , (181934,"Ellis")
    , (181417,"Stevens")
    , (178414,"Murray")
    , (178397,"Ford")
    , (177213,"Marshall")
    , (176334,"Owens")
    , (176094,"Mcdonald")
    , (175577,"Harrison")
    , (175429,"Ruiz")
    , (171636,"Kennedy")
    , (170635,"Wells")
    , (168817,"Alvarez")
    , (168814,"Woods")
    , (168567,"Mendoza")
    , (165473,"Castillo")
    , (163502,"Olson")
    , (163481,"Webb")
    , (163036,"Washington")
    , (162933,"Tucker")
    , (162686,"Freeman")
    , (162153,"Burns")
    , (161392,"Henry")
    , (159989,"Vasquez")
    , (159363,"Snyder")
    , (158241,"Simpson")
    , (158121,"Crawford")
    , (157475,"Jimenez")
    , (156848,"Porter")
    , (155484,"Mason")
    , (155172,"Shaw")
    , (154934,"Gordon")
    , (154516,"Wagner")
    , (154410,"Hunter")
    , (153772,"Romero")
    , (153618,"Hicks")
    , (152015,"Dixon")
    , (151986,"Hunt")
    , (150407,"Palmer")
    , (150299,"Robertson")
    , (150186,"Black")
    , (150166,"Holmes")
    , (149802,"Stone")
    , (149664,"Meyer")
    , (149476,"Boyd")
    , (147909,"Mills")
    , (147906,"Warren")
    , (147357,"Fox")
    , (146924,"Rose")
    , (146440,"Rice")
    , (146088,"Moreno")
    , (145565,"Schmidt")
    , (145066,"Patel")
    , (142256,"Ferguson")
    , (141936,"Nichols")
    , (140786,"Herrera")
    , (139353,"Medina")
    , (139335,"Ryan")
    , (139302,"Fernandez")
    , (138811,"Weaver")
    , (138776,"Daniels")
    , (138742,"Stephens")
    , (138660,"Gardner")
    , (138028,"Payne")
    , (137555,"Kelley")
    , (136955,"Dunn")
    , (136517,"Pierce")
    , (136315,"Arnold")
    , (136095,"Tran")
    , (134443,"Spencer")
    , (134231,"Peters")
    , (134066,"Hawkins")
    , (134034,"Grant")
    , (133474,"Hansen")
    , (133254,"Castro")
    , (132645,"Hoffman")
    , (132466,"Hart")
    , (132457,"Elliott")
    , (131896,"Cunningham")
    , (131860,"Knight")
    , (131289,"Bradley")
    ]

lastNameList02 :: [(Int, Text)]
lastNameList02 =
    [ (131020,"Carroll")
    , (130793,"Hudson")
    , (130419,"Duncan")
    , (129982,"Armstrong")
    , (129405,"Berry")
    , (129320,"Andrews")
    , (128935,"Johnston")
    , (128794,"Ray")
    , (128727,"Lane")
    , (127960,"Riley")
    , (127073,"Carpenter")
    , (126951,"Perkins")
    , (126399,"Aguilar")
    , (126164,"Silva")
    , (125653,"Richards")
    , (125627,"Willis")
    , (124839,"Matthews")
    , (124614,"Chapman")
    , (124321,"Lawrence")
    , (124130,"Garza")
    , (123952,"Vargas")
    , (122447,"Watkins")
    , (121684,"Wheeler")
    , (121064,"Larson")
    , (120124,"Carlson")
    , (119868,"Harper")
    , (119778,"George")
    , (119604,"Greene")
    , (119175,"Burke")
    , (118390,"Guzman")
    , (117939,"Morrison")
    , (117774,"Munoz")
    , (115540,"Jacobs")
    , (115385,"Obrien")
    , (115186,"Lawson")
    , (114859,"Franklin")
    , (114448,"Lynch")
    , (114034,"Bishop")
    , (113892,"Carr")
    , (113468,"Salazar")
    , (113160,"Austin")
    , (112736,"Mendez")
    , (112406,"Gilbert")
    , (112332,"Jensen")
    , (112216,"Williamson")
    , (112144,"Montgomery")
    , (112136,"Harvey")
    , (111641,"Oliver")
    , (109634,"Howell")
    , (109230,"Dean")
    , (109079,"Hanson")
    , (107866,"Weber")
    , (107777,"Garrett")
    , (107244,"Sims")
    , (107158,"Burton")
    , (106682,"Fuller")
    , (106631,"Soto")
    , (106481,"Mccoy")
    , (105804,"Welch")
    , (105544,"Chen")
    , (104962,"Schultz")
    , (104281,"Walters")
    , (104007,"Reid")
    , (103242,"Fields")
    , (103216,"Walsh")
    , (102718,"Little")
    , (102620,"Fowler")
    , (102239,"Bowman")
    , (102044,"Davidson")
    , (101726,"May")
    , (101676,"Day")
    , (100553,"Schneider")
    , (100491,"Newman")
    , (100465,"Brewer")
    , (100417,"Lucas")
    , (99885,"Holland")
    , (99392,"Wong")
    , (99294,"Banks")
    , (98993,"Santos")
    , (98958,"Curtis")
    , (98728,"Pearson")
    , (98675,"Delgado")
    , (98610,"Valdez")
    , (98345,"Pena")
    , (96569,"Rios")
    , (96425,"Douglas")
    , (96303,"Sandoval")
    , (95896,"Barrett")
    , (94603,"Hopkins")
    , (94300,"Keller")
    , (94152,"Guerrero")
    , (93817,"Stanley")
    , (93743,"Bates")
    , (93723,"Alvarado")
    , (93161,"Beck")
    , (93131,"Ortega")
    , (92834,"Wade")
    , (92831,"Estrada")
    , (92660,"Contreras")
    , (92287,"Barnett")
    ]

lastNameList03 :: [(Int, Text)]
lastNameList03 =
    [ (91338,"Caldwell")
    , (90967,"Santiago")
    , (90618,"Lambert")
    , (90401,"Powers")
    , (90325,"Chambers")
    , (90208,"Nunez")
    , (89591,"Craig")
    , (89198,"Leonard")
    , (89178,"Lowe")
    , (88917,"Rhodes")
    , (88811,"Byrd")
    , (88810,"Gregory")
    , (88326,"Shelton")
    , (88325,"Frazier")
    , (88114,"Becker")
    , (88016,"Maldonado")
    , (87949,"Fleming")
    , (87728,"Vega")
    , (87373,"Sutton")
    , (87226,"Cohen")
    , (87038,"Jennings")
    , (86346,"Parks")
    , (86317,"Mcdaniel")
    , (86228,"Watts")
    , (85221,"Barker")
    , (85212,"Norris")
    , (85037,"Vaughn")
    , (84926,"Vazquez")
    , (84710,"Holt")
    , (84699,"Schwartz")
    , (84353,"Steele")
    , (84233,"Benson")
    , (83849,"Neal")
    , (83731,"Dominguez")
    , (83523,"Horton")
    , (83437,"Terry")
    , (83112,"Wolfe")
    , (82955,"Hale")
    , (82258,"Lyons")
    , (82179,"Graves")
    , (82037,"Haynes")
    , (81933,"Miles")
    , (81890,"Park")
    , (81824,"Warner")
    , (81805,"Padilla")
    , (81524,"Bush")
    , (81191,"Thornton")
    , (81035,"Mccarthy")
    , (81022,"Mann")
    , (80944,"Zimmerman")
    , (80936,"Erickson")
    , (80932,"Fletcher")
    , (80616,"Mckinney")
    , (80493,"Page")
    , (80190,"Dawson")
    , (80030,"Joseph")
    , (79951,"Marquez")
    , (79817,"Reeves")
    , (79685,"Klein")
    , (79322,"Espinoza")
    , (79151,"Baldwin")
    , (78546,"Moran")
    , (78323,"Love")
    , (78141,"Robbins")
    , (78107,"Higgins")
    , (77561,"Ball")
    , (77492,"Cortez")
    , (77453,"Le")
    , (77429,"Griffith")
    , (77078,"Bowen")
    , (76868,"Sharp")
    , (76707,"Cummings")
    , (76625,"Ramsey")
    , (76608,"Hardy")
    , (76539,"Swanson")
    , (76504,"Barber")
    , (76477,"Acosta")
    , (76127,"Luna")
    , (76114,"Chandler")
    , (75135,"Blair")
    , (75135,"Daniel")
    , (75134,"Cross")
    , (74839,"Simon")
    , (74784,"Dennis")
    , (74756,"Oconnor")
    , (74531,"Quinn")
    , (74285,"Gross")
    , (73970,"Navarro")
    , (73750,"Moss")
    , (73522,"Fitzgerald")
    , (73518,"Doyle")
    , (73128,"Mclaughlin")
    , (73071,"Rojas")
    , (73021,"Rodgers")
    , (72892,"Stevenson")
    , (72642,"Singh")
    , (72627,"Yang")
    , (72533,"Figueroa")
    , (72414,"Harmon")
    , (72328,"Newton")
    ]

lastNameList04 :: [(Int, Text)]
lastNameList04 =
    [ (72248,"Paul")
    , (72069,"Manning")
    , (72052,"Garner")
    , (71925,"Mcgee")
    , (71754,"Reese")
    , (71723,"Francis")
    , (71604,"Burgess")
    , (71528,"Adkins")
    , (71482,"Goodman")
    , (71344,"Curry")
    , (71175,"Brady")
    , (71144,"Christensen")
    , (71103,"Potter")
    , (70997,"Walton")
    , (70333,"Goodwin")
    , (70286,"Mullins")
    , (70211,"Molina")
    , (70123,"Webster")
    , (70095,"Fischer")
    , (69950,"Campos")
    , (69843,"Avila")
    , (69840,"Sherman")
    , (69810,"Todd")
    , (69756,"Chang")
    , (69279,"Blake")
    , (69257,"Malone")
    , (68905,"Wolf")
    , (68868,"Hodges")
    , (68785,"Juarez")
    , (68699,"Gill")
    , (68309,"Farmer")
    , (68145,"Hines")
    , (68075,"Gallagher")
    , (68046,"Duran")
    , (68021,"Hubbard")
    , (67923,"Cannon")
    , (67646,"Miranda")
    , (67570,"Wang")
    , (67210,"Saunders")
    , (67208,"Tate")
    , (67154,"Mack")
    , (67063,"Hammond")
    , (67054,"Carrillo")
    , (66853,"Townsend")
    , (66738,"Wise")
    , (66665,"Ingram")
    , (66622,"Barton")
    , (66534,"Mejia")
    , (66515,"Ayala")
    , (66412,"Schroeder")
    , (66378,"Hampton")
    , (66205,"Rowe")
    , (66203,"Parsons")
    , (65918,"Frank")
    , (65817,"Waters")
    , (65814,"Strickland")
    , (65802,"Osborne")
    , (65779,"Maxwell")
    , (65719,"Chan")
    , (65598,"Deleon")
    , (65269,"Norman")
    , (65131,"Harrington")
    , (64815,"Casey")
    , (64772,"Patton")
    , (64576,"Logan")
    , (64496,"Bowers")
    , (64305,"Mueller")
    , (64180,"Glover")
    , (64141,"Floyd")
    , (63827,"Hartman")
    , (63825,"Buchanan")
    , (63739,"Cobb")
    , (63149,"French")
    , (63023,"Kramer")
    , (62663,"Mccormick")
    , (62546,"Clarke")
    , (62534,"Tyler")
    , (62514,"Gibbs")
    , (62344,"Moody")
    , (62335,"Conner")
    , (62234,"Sparks")
    , (62116,"Mcguire")
    , (62034,"Leon")
    , (61979,"Bauer")
    , (61805,"Norton")
    , (61750,"Pope")
    , (61747,"Flynn")
    , (61651,"Hogan")
    , (61619,"Robles")
    , (61582,"Salinas")
    , (61400,"Yates")
    , (61199,"Lindsey")
    , (61154,"Lloyd")
    , (60999,"Marsh")
    , (60874,"Mcbride")
    , (60461,"Owen")
    , (60045,"Solis")
    , (59949,"Pham")
    , (59843,"Lang")
    , (59801,"Pratt")
    ]

lastNameList05 :: [(Int, Text)]
lastNameList05 =
    [ (59731,"Lara")
    , (59682,"Brock")
    , (59660,"Ballard")
    , (59609,"Trujillo")
    , (59227,"Shaffer")
    , (59055,"Drake")
    , (59020,"Roman")
    , (58918,"Aguirre")
    , (58788,"Morton")
    , (58687,"Stokes")
    , (58555,"Lamb")
    , (58534,"Pacheco")
    , (58257,"Patrick")
    , (58233,"Cochran")
    , (57935,"Shepherd")
    , (57873,"Cain")
    , (57859,"Burnett")
    , (57822,"Hess")
    , (57786,"Li")
    , (57685,"Cervantes")
    , (57357,"Olsen")
    , (57297,"Briggs")
    , (57210,"Ochoa")
    , (57171,"Cabrera")
    , (57163,"Velasquez")
    , (57075,"Montoya")
    , (57030,"Roth")
    , (56744,"Meyers")
    , (56618,"Cardenas")
    , (56441,"Fuentes")
    , (56153,"Weiss")
    , (56068,"Hoover")
    , (56068,"Wilkins")
    , (55986,"Nicholson")
    , (55973,"Underwood")
    , (55903,"Short")
    , (55821,"Carson")
    , (55664,"Morrow")
    , (55512,"Colon")
    , (55466,"Holloway")
    , (55391,"Summers")
    , (55269,"Bryan")
    , (55185,"Petersen")
    , (55084,"Mckenzie")
    , (55057,"Serrano")
    , (54987,"Wilcox")
    , (54924,"Carey")
    , (54875,"Clayton")
    , (54706,"Poole")
    , (54691,"Calderon")
    , (54672,"Gallegos")
    , (54611,"Greer")
    , (54588,"Rivas")
    , (54575,"Guerra")
    , (54450,"Decker")
    , (54414,"Collier")
    , (54401,"Wall")
    , (54343,"Whitaker")
    , (54296,"Bass")
    , (54277,"Flowers")
    , (54206,"Davenport")
    , (54194,"Conley")
    , (54026,"Houston")
    , (53892,"Huff")
    , (53771,"Copeland")
    , (53737,"Hood")
    , (53475,"Monroe")
    , (53459,"Massey")
    , (53198,"Roberson")
    , (53180,"Combs")
    , (53161,"Franco")
    , (52963,"Larsen")
    , (52689,"Pittman")
    , (52495,"Randall")
    , (52490,"Skinner")
    , (52483,"Wilkinson")
    , (52473,"Kirby")
    , (52439,"Cameron")
    , (52260,"Bridges")
    , (52146,"Anthony")
    , (52138,"Richard")
    , (52056,"Kirk")
    , (52004,"Bruce")
    , (51797,"Singleton")
    , (51796,"Mathis")
    , (51726,"Bradford")
    , (51679,"Boone")
    , (51620,"Abbott")
    , (51518,"Charles")
    , (51504,"Allison")
    , (51500,"Sweeney")
    , (51489,"Atkinson")
    , (51380,"Horn")
    , (51361,"Jefferson")
    , (51336,"Rosales")
    , (51334,"York")
    , (51177,"Christian")
    , (51154,"Phelps")
    , (51095,"Farrell")
    , (51089,"Castaneda")
    ]

lastNameList06 :: [(Int, Text)]
lastNameList06 =
    [ (51021,"Nash")
    , (51017,"Dickerson")
    , (50980,"Bond")
    , (50874,"Wyatt")
    , (50852,"Foley")
    , (50777,"Chase")
    , (50748,"Gates")
    , (50628,"Vincent")
    , (50608,"Mathews")
    , (50577,"Hodge")
    , (50482,"Garrison")
    , (50454,"Trevino")
    , (50351,"Villarreal")
    , (50307,"Heath")
    , (50166,"Dalton")
    , (50026,"Valencia")
    , (49925,"Callahan")
    , (49858,"Hensley")
    , (49754,"Atkins")
    , (49737,"Huffman")
    , (49725,"Roy")
    , (49601,"Boyer")
    , (49556,"Shields")
    , (49360,"Lin")
    , (49330,"Hancock")
    , (49245,"Grimes")
    , (49241,"Glenn")
    , (49167,"Cline")
    , (49158,"Delacruz")
    , (49000,"Camacho")
    , (48833,"Dillon")
    , (48823,"Parrish")
    , (48656,"Oneill")
    , (48594,"Melton")
    , (48580,"Booth")
    , (48527,"Kane")
    , (48480,"Berg")
    , (48471,"Harrell")
    , (48462,"Pitts")
    , (48367,"Savage")
    , (48355,"Wiggins")
    , (48296,"Brennan")
    , (48282,"Salas")
    , (48281,"Marks")
    , (48126,"Russo")
    , (47979,"Sawyer")
    , (47857,"Baxter")
    , (47839,"Golden")
    , (47809,"Hutchinson")
    , (47665,"Liu")
    , (47615,"Walter")
    , (47526,"Mcdowell")
    , (47503,"Wiley")
    , (47477,"Rich")
    , (47470,"Humphrey")
    , (47289,"Johns")
    , (47286,"Koch")
    , (47235,"Suarez")
    , (47220,"Hobbs")
    , (47128,"Beard")
    , (47050,"Gilmore")
    , (46895,"Ibarra")
    , (46747,"Keith")
    , (46739,"Macias")
    , (46713,"Khan")
    , (46702,"Andrade")
    , (46682,"Ware")
    , (46662,"Stephenson")
    , (46609,"Henson")
    , (46605,"Wilkerson")
    , (46574,"Dyer")
    , (46505,"Mcclure")
    , (46495,"Blackwell")
    , (46437,"Mercado")
    , (46412,"Tanner")
    , (46403,"Eaton")
    , (46264,"Clay")
    , (46196,"Barron")
    , (46179,"Beasley")
    , (46161,"Oneal")
    , (45850,"Preston")
    , (45850,"Small")
    , (45815,"Wu")
    , (45806,"Zamora")
    , (45782,"Macdonald")
    , (45763,"Vance")
    , (45689,"Snow")
    , (45560,"Mcclain")
    , (45349,"Stafford")
    , (45289,"Orozco")
    , (45044,"Barry")
    , (45032,"English")
    , (44902,"Shannon")
    , (44900,"Kline")
    , (44874,"Jacobson")
    , (44830,"Woodard")
    , (44715,"Huang")
    , (44701,"Kemp")
    , (44698,"Mosley")
    , (44640,"Prince")
    ]

lastNameList07 :: [(Int, Text)]
lastNameList07 =
    [ (44626,"Merritt")
    , (44587,"Hurst")
    , (44570,"Villanueva")
    , (44454,"Roach")
    , (44421,"Nolan")
    , (44385,"Lam")
    , (44245,"Yoder")
    , (44123,"Mccullough")
    , (43919,"Lester")
    , (43875,"Santana")
    , (43770,"Valenzuela")
    , (43762,"Winters")
    , (43720,"Barrera")
    , (43666,"Leach")
    , (43666,"Orr")
    , (43556,"Berger")
    , (43555,"Mckee")
    , (43430,"Strong")
    , (43395,"Conway")
    , (43331,"Stein")
    , (43310,"Whitehead")
    , (43021,"Bullock")
    , (42955,"Escobar")
    , (42937,"Knox")
    , (42884,"Meadows")
    , (42839,"Solomon")
    , (42820,"Velez")
    , (42802,"Odonnell")
    , (42758,"Kerr")
    , (42669,"Stout")
    , (42663,"Blankenship")
    , (42642,"Browning")
    , (42597,"Kent")
    , (42567,"Lozano")
    , (42512,"Bartlett")
    , (42463,"Pruitt")
    , (42441,"Buck")
    , (42432,"Barr")
    , (42369,"Gaines")
    , (42365,"Durham")
    , (42357,"Gentry")
    , (42335,"Mcintyre")
    , (42281,"Sloan")
    , (42139,"Melendez")
    , (42139,"Rocha")
    , (42091,"Herman")
    , (42080,"Sexton")
    , (42062,"Moon")
    , (41879,"Hendricks")
    , (41868,"Rangel")
    , (41863,"Stark")
    , (41670,"Lowery")
    , (41664,"Hardin")
    , (41656,"Hull")
    , (41561,"Sellers")
    , (41459,"Ellison")
    , (41452,"Calhoun")
    , (41393,"Gillespie")
    , (41348,"Mora")
    , (41267,"Knapp")
    , (41231,"Mccall")
    , (41112,"Morse")
    , (41104,"Dorsey")
    , (41053,"Weeks")
    , (41007,"Nielsen")
    , (40964,"Livingston")
    , (40923,"Leblanc")
    , (40871,"Mclean")
    , (40794,"Bradshaw")
    , (40724,"Glass")
    , (40708,"Middleton")
    , (40706,"Buckley")
    , (40663,"Schaefer")
    , (40582,"Frost")
    , (40555,"Howe")
    , (40477,"House")
    , (40453,"Mcintosh")
    , (40413,"Ho")
    , (40339,"Pennington")
    , (40310,"Reilly")
    , (40283,"Hebert")
    , (40244,"Mcfarland")
    , (40224,"Hickman")
    , (40217,"Noble")
    , (40203,"Spears")
    , (40102,"Conrad")
    , (40086,"Arias")
    , (40046,"Galvan")
    , (40030,"Velazquez")
    , (40011,"Huynh")
    , (39909,"Frederick")
    , (39742,"Randolph")
    , (39601,"Cantu")
    , (39501,"Fitzpatrick")
    , (39440,"Mahoney")
    , (39432,"Peck")
    , (39402,"Villa")
    , (39369,"Michael")
    , (39270,"Donovan")
    , (39203,"Mcconnell")
    ]

lastNameList08 :: [(Int, Text)]
lastNameList08 =
    [ (39166,"Walls")
    , (39141,"Boyle")
    , (39111,"Mayer")
    , (39057,"Zuniga")
    , (39002,"Giles")
    , (38999,"Pineda")
    , (38975,"Pace")
    , (38971,"Hurley")
    , (38914,"Mays")
    , (38896,"Mcmillan")
    , (38844,"Crosby")
    , (38836,"Ayers")
    , (38759,"Case")
    , (38714,"Bentley")
    , (38705,"Shepard")
    , (38702,"Everett")
    , (38691,"Pugh")
    , (38659,"David")
    , (38557,"Mcmahon")
    , (38516,"Dunlap")
    , (38464,"Bender")
    , (38354,"Hahn")
    , (38340,"Harding")
    , (38232,"Acevedo")
    , (38158,"Raymond")
    , (38137,"Blackburn")
    , (37962,"Duffy")
    , (37961,"Landry")
    , (37903,"Dougherty")
    , (37847,"Bautista")
    , (37833,"Shah")
    , (37687,"Potts")
    , (37678,"Arroyo")
    , (37669,"Valentine")
    , (37662,"Meza")
    , (37660,"Gould")
    , (37591,"Vaughan")
    , (37542,"Fry")
    , (37470,"Rush")
    , (37440,"Avery")
    , (37353,"Herring")
    , (37298,"Dodson")
    , (37237,"Clements")
    , (37234,"Sampson")
    , (37201,"Tapia")
    , (37145,"Bean")
    , (37125,"Lynn")
    , (37123,"Crane")
    , (37116,"Farley")
    , (37050,"Cisneros")
    , (37032,"Benton")
    , (37021,"Ashley")
    , (36948,"Mckay")
    , (36874,"Finley")
    , (36862,"Best")
    , (36841,"Blevins")
    , (36833,"Friedman")
    , (36814,"Moses")
    , (36813,"Sosa")
    , (36764,"Blanchard")
    , (36729,"Huber")
    , (36716,"Frye")
    , (36694,"Krueger")
    , (36546,"Bernard")
    , (36539,"Rosario")
    , (36531,"Rubio")
    , (36442,"Mullen")
    , (36439,"Benjamin")
    , (36433,"Haley")
    , (36422,"Chung")
    , (36421,"Moyer")
    , (36390,"Choi")
    , (36288,"Horne")
    , (36285,"Yu")
    , (36242,"Woodward")
    , (36079,"Ali")
    , (36037,"Nixon")
    , (36024,"Hayden")
    , (35980,"Rivers")
    , (35839,"Estes")
    , (35718,"Mccarty")
    , (35715,"Richmond")
    , (35701,"Stuart")
    , (35648,"Maynard")
    , (35616,"Brandt")
    , (35610,"Oconnell")
    , (35599,"Hanna")
    , (35565,"Sanford")
    , (35554,"Sheppard")
    , (35539,"Church")
    , (35521,"Burch")
    , (35464,"Levy")
    , (35453,"Rasmussen")
    , (35442,"Coffey")
    , (35400,"Ponce")
    , (35389,"Faulkner")
    , (35387,"Donaldson")
    , (35326,"Schmitt")
    , (35282,"Novak")
    , (35227,"Costa")
    ]

lastNameList09 :: [(Int, Text)]
lastNameList09 =
    [ (35196,"Montes")
    , (35101,"Booker")
    , (35074,"Cordova")
    , (35001,"Waller")
    , (34999,"Arellano")
    , (34970,"Maddox")
    , (34888,"Mata")
    , (34824,"Bonilla")
    , (34812,"Stanton")
    , (34788,"Compton")
    , (34786,"Kaufman")
    , (34770,"Dudley")
    , (34763,"Mcpherson")
    , (34736,"Beltran")
    , (34698,"Dickson")
    , (34692,"Mccann")
    , (34684,"Villegas")
    , (34682,"Proctor")
    , (34675,"Hester")
    , (34674,"Cantrell")
    , (34650,"Daugherty")
    , (34615,"Cherry")
    , (34575,"Bray")
    , (34541,"Davila")
    , (34498,"Rowland")
    , (34472,"Levine")
    , (34472,"Madden")
    , (34435,"Spence")
    , (34430,"Good")
    , (34374,"Irwin")
    , (34352,"Werner")
    , (34345,"Krause")
    , (34278,"Petty")
    , (34251,"Whitney")
    , (34233,"Baird")
    , (34084,"Hooper")
    , (34079,"Pollard")
    , (34068,"Zavala")
    , (34050,"Jarvis")
    , (34041,"Holden")
    , (34032,"Haas")
    , (34032,"Hendrix")
    , (34031,"Mcgrath")
    , (33962,"Bird")
    , (33922,"Lucero")
    , (33914,"Terrell")
    , (33868,"Riggs")
    , (33843,"Joyce")
    , (33797,"Mercer")
    , (33797,"Rollins")
    , (33773,"Galloway")
    , (33745,"Duke")
    , (33717,"Odom")
    , (33508,"Andersen")
    , (33494,"Downs")
    , (33464,"Hatfield")
    , (33441,"Benitez")
    , (33411,"Archer")
    , (33348,"Huerta")
    , (33339,"Travis")
    , (33239,"Mcneil")
    , (33209,"Hinton")
    , (33202,"Zhang")
    , (33194,"Hays")
    , (33126,"Mayo")
    , (33068,"Fritz")
    , (33040,"Branch")
    , (32953,"Mooney")
    , (32925,"Ewing")
    , (32864,"Ritter")
    , (32772,"Esparza")
    , (32735,"Frey")
    , (32676,"Braun")
    , (32672,"Gay")
    , (32654,"Riddle")
    , (32644,"Haney")
    , (32567,"Kaiser")
    , (32466,"Holder")
    , (32433,"Chaney")
    , (32386,"Mcknight")
    , (32377,"Gamble")
    , (32333,"Vang")
    , (32287,"Cooley")
    , (32282,"Carney")
    , (32242,"Cowan")
    , (32228,"Forbes")
    , (32174,"Ferrell")
    , (32165,"Davies")
    , (32147,"Barajas")
    , (32069,"Shea")
    , (32044,"Osborn")
    , (32042,"Bright")
    , (32015,"Cuevas")
    , (31995,"Bolton")
    , (31964,"Murillo")
    , (31940,"Lutz")
    , (31896,"Duarte")
    , (31886,"Kidd")
    , (31882,"Key")
    , (31860,"Cooke")
    ]
